.. _getting_started:

Getting started
===============

The :ref:`installation guide <installing>` provides information on getting up and running.
Some guides and tutorials demonstrating how to get started running cartopy

.. toctree::
    :maxdepth: 2

    crs.rst
    ../matplotlib/intro.rst
    ../matplotlib/feature_interface.rst
    ../tutorials/understanding_transform.rst
    ../tutorials/using_the_shapereader.rst
    ../developer_interfaces.rst


The :ref:`API Reference <api>` link can be used to
quickly find the reference documentation for known classes or functions.

For those updating from an older version of cartopy, the :ref:`what's new <release>` page
outlines recent changes, new features, and future development plans.

Once you've gotten started with cartopy, consider citing it, including copyright
attributions for data, and becoming a contributor on the project.

.. toctree::

    ../contribute
    ../citation
    ../copyright
    ../contributors
